==> keras_bed_sequence-1.0.10.tar.gz: keras_bed_sequence-1.0.10/setup.py <==
import os
import re
# To use a consistent encoding
from codecs import open as copen

from setuptools import find_packages, setup

here = os.path.abspath(os.path.dirname(__file__))

# Get the long description from the relevant file
with copen(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()


def read(*parts):
    with copen(os.path.join(here, *parts), 'r') as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


__version__ = find_version("keras_bed_sequence", "__version__.py")

test_deps = [
    "pytest",
    "pytest-cov",
    "coveralls",
    "validate_version_code",
    "codacy-coverage",
    "silence_tensorflow"
]

extras = {
    'test': test_deps,
}

setup(
    name='keras_bed_sequence',
    version=__version__,
    description="Lazily one-hot encoding bed sequences using Keras Sequence.",
    long_description=long_description,
    url="https://github.com/LucaCappelletti94/keras_bed_sequence",
    author="Luca Cappelletti",
    author_email="cappelletti.luca94@gmail.com",
    # Choose your license
    license='MIT',
    include_package_data=True,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3'
    ],
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),
    tests_require=test_deps,
    # Add here the package dependencies
    install_requires=[
        "numpy",
        "pandas",
        "tensorflow",
        "keras_mixed_sequence",
        "ucsc_genomes_downloader"
    ],
    extras_require=extras,
)

==> keras_bed_sequence-1.0.12.tar.gz: keras_bed_sequence-1.0.12/setup.py <==
import os
import re
# To use a consistent encoding
from codecs import open as copen

from setuptools import find_packages, setup

here = os.path.abspath(os.path.dirname(__file__))

# Get the long description from the relevant file
with copen(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()


def read(*parts):
    with copen(os.path.join(here, *parts), 'r') as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


__version__ = find_version("keras_bed_sequence", "__version__.py")

test_deps = [
    "pytest",
    "pytest-cov",
    "coveralls",
    "validate_version_code",
    "codacy-coverage",
    "silence_tensorflow"
]

extras = {
    'test': test_deps,
}

setup(
    name='keras_bed_sequence',
    version=__version__,
    description="Lazily one-hot encoding bed sequences using Keras Sequence.",
    long_description=long_description,
    url="https://github.com/LucaCappelletti94/keras_bed_sequence",
    author="Luca Cappelletti",
    author_email="cappelletti.luca94@gmail.com",
    # Choose your license
    license='MIT',
    include_package_data=True,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3'
    ],
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),
    tests_require=test_deps,
    # Add here the package dependencies
    install_requires=[
        "numpy",
        "pandas",
        "tensorflow",
        "keras_mixed_sequence>=1.0.5",
        "ucsc_genomes_downloader>=1.1.13"
    ],
    extras_require=extras,
)
